#=====================================================================
#
# PS-Audit v2.3 (a component of the PS-NetMon project)
#
# This script creates CFG files from a single server. The server
# audited may be either named or by IP address. Once an audit is
# performed the CFG file is created in the DISCOVER directory and you
# will be prompted to enter another server. A blank entry in the
# server name prompt will exit the script. Mass imports to this script
# may be accomplished with the PS-Discover.PS1 script. This script
# should not be edited.
#
# Full documentation for this script is found online.
#
# This script and more to help manage your network found, managed and 
# happily shared with documentation on usage at the IP WORk eXchange.
#                   http://www.IPWORX.com
#
#=====================================================================

param([string]$server)

cls
$scriptrun = $false
$ErrorActionPreference = "SilentlyContinue"

:nextserverplease while(1){

    if ($server -gt ""){
        $scriptrun = $true
    }
    Else{
        $server = Read-Host 'Server name to audit?'
        if ($server -eq "") {Exit}
    }

    new-item -itemtype directory -force -path "$PSScriptRoot\DISCOVER" | out-null


    $server = $server.ToUpper()
    Set-Location $PSScriptRoot
    $ConnectSuccess=$false

    Function PingHost ([string] $server,[int]$count) {
        if ($count -lt 1){$count = 2}
        $ping = Test-Connection -ComputerName $server -ErrorAction Silentlycontinue -Count $count
        if ($ping.statuscode -ne 0) {
            write-host "`n`nPING unavailable on $server, check firewalls and permissions.`nMake sure PING is available.`n"
            return $false
        } 
        else { 
            $script:ConnectSuccess=$true
            return $true 
        }
    } 

    Function WMIPinghost ([string] $Hostname ) { 
        $ping = get-wmiobject -query "select * from Win32_Bios" -computername $Hostname -ErrorAction Silentlycontinue 
        if ($ping.name -gt "") { 
            $script:ConnectSuccess=$true
            return $true 
        } 
        else {
            write-host "`n`nWMI unavailable on $Hostname, check firewalls and permissions.`nMake sure WMI is available.`n"
            return $false
        } 
    } 


    if (WMIPingHost $server){
        #audit services==============
        #load common services to omit from audit
        $header = "Name","DisplayName"
        $commonservices = import-csv CommonServices.cfg -header $header
        $error.clear()
        $servicelist = ""
        $services = Get-WmiObject Win32_Service -computername $server
        $services = $services | where {$_.state -eq "running"} | where {$_.DisplayName -notin $commonservices.DisplayName}
        $services = $services | select-object Name,DisplayName | convertto-csv -NoTypeInformation | Select-Object -Skip 1
        $servicelist = $services | %{"SERVICE,$_"}  | out-string

        #audit drives================
        $drives = Get-WmiObject Win32_LogicalDisk -ComputerName $server | Where-Object {$_.FreeSpace -gt 0} | Select-Object DeviceID,Size,FreeSpace -ExpandProperty DeviceID
        $drivelist = $drives | %{"DRIVE,$_,10"} | out-string

        $auditlist = $servicelist + $drivelist
        $auditlist = $auditlist + "EVENT,system,critical`r`n"
        $auditlist = $auditlist + "EVENT,application,critical`r`n"
        $auditlist = $auditlist + "CPU,90`r`n"
        $auditlist = $auditlist + "RAM,90`r`n"
        $auditlist = $auditlist + "VRAM,90`r`n"
    }

    if (PingHost $server){
        $auditlist = $auditlist + "PING,2`r`n"
    }

    if ($ConnectSuccess){
        $auditlist = "SERVER,$server`r`n" + $auditlist
        $outfilename = "$PSScriptRoot\DISCOVER\Server.$server.cfg"
        write-host $auditlist
        $auditlist | out-file $outfilename

        write-host "File ""$outfilename"" created.`n"
    }

    write-host "audit complete`r`n`r`n`r`n"

    $server = ""
    $auditlist = ""
    $servicelist = ""
    $drivelist = ""
    $services = ""
    $drives = ""

    if ($scriptrun -eq $true){break nextserverplease}
}

