#=====================================================================
#
# PS-Discover v2.3 (a component of the PS-NetMon project)
#
# This script is used to import device lists and systematically launch
# PS-Audit.PS1 to audit devices stored in;
#
#      1) file list (one device per line)
#      2) Active Directory OU
#   or 3) Class C subnet. 
#
# Audit CFG file results stored in DISOVER sub-directory. This script
# should not be edited.
#
# Full documentation for this script is found online.
#
# This script and more to help manage your network found, managed and 
# happily shared with documentation on usage at the IP WORk eXchange.
#                   http://www.IPWORX.com
#
#=====================================================================

Function Audit-Server([string]$srv){
    $arg = "$PSScriptRoot\PS-Audit.ps1 -server $srv"
    write-host "Auditing $srv..."
    Start-Process PowerShell -windowstyle Hidden -Arg "$arg"  
}

Function Import-File(){
    cls
    $fd = New-Object system.windows.forms.openfiledialog
    $fd.InitialDirectory = $PSScriptRootin
    $fd.MultiSelect = $false
    $fd.showdialog()
    $fd.filenames

    $fname = $fd.filename | out-string
    $fname = $fname -replace "`n",""
    $fname = $fname -replace "`r",""

    if ($fname -gt "") {Get-Content $fname | Foreach-Object {Audit-Server -srv $_ }}
}

Function Import-AD(){
    Import-Module ActiveDirectory
    $ADBase = Read-Host 'AD Base OU (ex: OU=Servers,DC=domain,DC=com)?'
    if ($ADBase -gt "") {Get-ADComputer -Filter * -SearchBase $ADBase | select -expandproperty name | Foreach-Object {Audit-Server -srv $_ }}
}

Function ResolveDNS([string]$ipaddress){
    $ErrorActionPreference = "SilentlyContinue"
    $error.clear()
    $hostname = ""

    write-host $ipaddress

    $hostentry = [System.Net.Dns]::GetHostEntry($ipaddress)
    $hostname = "" + $($hostentry.hostname)
    if ($error.count -gt 0){$hostname = $ipaddress}

    return $hostname
}

Function MakeIPList([string]$start){
    $iplist = @()
    $x = 1
    if ($start.Substring($start.length -1,1) -ne "."){$start = "$start."}
    do {
        $iplist += "$start$x"
        $x++
    }
    while ($x -lt 255)

    return $iplist
}

Function Import-Net(){
    $ipstart = read-host "First three octets for network scan (192.168.1)?"
    if ($ipstart -gt "") {MakeIPList $ipstart | foreach-object {ResolveDNS $_ } | Foreach-Object {Audit-Server -srv $_ }}
}




#================== CORE ========================
cls
$ErrorActionPreference = "SilentlyContinue"
$discoverytype = ""
while($discoverytype -ne "f" -and $discoverytype -ne "a" -and $discoverytype -ne "n"){
    $discoverytype = Read-Host 'DISCOVERY: (F)ile import, (A)ctive Directory, or (N)etwork Sweep'
}

switch ($discoverytype)
    {
        "a" {Import-AD}
        "f" {Import-File}
        "n" {Import-Net}
    }
